@@ -5,7 +5,7 @@ import pycares
 from . import error
 
 
-__version__ = '0.2.0'
+__version__ = '0.3.0'
 
 __all__ = ('DNSResolver', 'error')
 
@@ -34,7 +34,7 @@ class DNSResolver(object):
         kwargs.pop('sock_state_cb', None)
         self._channel = pycares.Channel(sock_state_cb=self._sock_state_cb, **kwargs)
         if nameservers:
-            self._channel.servers = nameservers
+            self.nameservers = nameservers
         self._fds = set()
         self._timer = None
 
@@ -53,6 +53,8 @@ class DNSResolver(object):
             raise ValueError('invalid query type: {}'.format(qtype))
         fut = asyncio.Future(loop=self.loop)
         def cb(result, errorno):
+            if fut.cancelled():
+                return
             if errorno is not None:
                 fut.set_exception(error.DNSError(errorno, pycares.errno.strerror(errorno)))
             else:
@@ -60,6 +62,9 @@ class DNSResolver(object):
         self._channel.query(host, qtype, cb)
         return fut
 
+    def cancel(self):
+        self._channel.cancel()
+
     def _sock_state_cb(self, fd, readable, writable):
         if readable or writable:
             if readable:
